Enum WaveletSpec
#[non_exhaustive]pub enum WaveletSpec {
Haar,
Daubechies {
order: usize,
},
Symlet {
order: usize,
},
Coiflet {
order: usize,
},
Biorthogonal {
kind: BiorthogonalSpec,
},
}Expand description
Product-facing wavelet selector.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Haar
Haar wavelet.
Daubechies
Daubechies wavelet by supported order: 2, 4, 6, 8, or 10.
Symlet
Symlet wavelet by supported order: 2 through 10.
Coiflet
Coiflet wavelet by supported order: 1 through 5.
Biorthogonal
Biorthogonal CDF wavelet.
Fields

kind: BiorthogonalSpecImplementations
impl WaveletSpec
impl WaveletSpec
pub fn build_discrete(self) -> Result<Box<dyn Wavelet>>
pub fn build_discrete(self) -> Result<Box<dyn Wavelet>>
Build a core discrete wavelet from this product spec.
pub fn validate(self) -> Result<()>
pub fn validate(self) -> Result<()>
Validate the wavelet selector without exposing raw transform internals.
pub fn stable_name(self) -> String
pub fn stable_name(self) -> String
Stable wire-friendly wavelet name.