Struct VolatilityHorizon
#[non_exhaustive]pub struct VolatilityHorizon {
pub level: Option<usize>,
pub period_span: Option<usize>,
pub label: String,
pub contribution_pct: f64,
}Expand description
Dominant volatility horizon.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.level: Option<usize>One-based detail level, or None when the smooth component dominates.
period_span: Option<usize>Horizon span in input periods, or None for the smooth component.
label: StringStable product-facing horizon label.
contribution_pct: f64Percentage contribution to total component variance.